@@ -1,27 +1,34 @@
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import _ from 'lodash'
 import {
     AcmAlert,
     AcmButton,
     AcmDropdown,
-    AcmLaunchLink,
+    AcmIconVariant,
+    AcmIcon,
     AcmPage,
-    AcmPageHeader,
+    AcmRoute,
     AcmScrollable,
     AcmSearchbar,
     AcmActionGroup,
-} from '@stolostron/ui-components'
-import { PageSection } from '@patternfly/react-core'
+} from '@open-cluster-management/ui-components'
+import { PageSection, ButtonVariant } from '@patternfly/react-core'
 import '@patternfly/react-core/dist/styles/base.css'
 import React, { Fragment, useState, useEffect } from 'react'
 import { useTranslation } from 'react-i18next'
+import { useRecoilState } from 'recoil'
+import { acmRouteState } from '../../util'
 import { searchClient } from '../../search-sdk/search-client'
 import SavedSearchQueries from './components/SavedSearchQueries'
 import SearchResults from './components/SearchResults'
+import HeaderWithNotification from './components/HeaderWithNotification'
 import {
     useSearchSchemaQuery,
     useSearchCompleteQuery,
     useSavedSearchesQuery,
     UserSearch,
+    useGetMessagesQuery,
 } from '../../search-sdk/search-sdk'
 import { convertStringToQuery, formatSearchbarSuggestions, getSearchCompleteString } from './search-helper'
 import { updateBrowserUrl, transformBrowserUrlToSearchString } from './urlQuery'
@@ -54,10 +61,18 @@ function HandleErrors(schemaError: ApolloError | undefined, completeError: Apoll
             <div style={{ marginBottom: '1rem' }}>
                 <AcmAlert
                     noClose
-                    variant={'danger'}
+                    variant={
+                        schemaError?.message.includes('not enabled') || completeError?.message.includes('not enabled')
+                            ? 'info'
+                            : 'danger'
+                    }
                     isInline
-                    title={t('search.filter.errors.title')}
-                    subtitle={t('search.filter.errors.description')}
+                    title={
+                        schemaError?.message.includes('not enabled') || completeError?.message.includes('not enabled')
+                            ? t('search.filter.info.title')
+                            : t('search.filter.errors.title')
+                    }
+                    subtitle={schemaError?.message || completeError?.message}
                 />
             </div>
         )
@@ -94,14 +109,15 @@ function RenderSearchBar(props: {
             query: searchCompleteQuery,
         },
     })
-    if (
-        (!searchSchemaResults.data && searchSchemaResults.error) ||
-        (!searchCompleteResults.data && searchCompleteResults.error)
-    ) {
-        setQueryErrors(true)
-    } else if (queryErrors) {
-        setQueryErrors(false)
-    }
+
+    useEffect(() => {
+        if (searchSchemaResults?.error || searchCompleteResults?.error) {
+            setQueryErrors(true)
+        } else if (queryErrors) {
+            setQueryErrors(false)
+        }
+    }, [searchSchemaResults, searchCompleteResults, queryErrors, setQueryErrors])
+
     return (
         <Fragment>
             <PageSection>
@@ -206,13 +222,26 @@ function RenderDropDownAndNewTab(props: {
         <div className={classes.actionGroup}>
             <AcmActionGroup>
                 <SavedSearchDropdown selectedSearch={props.selectedSearch} />
-                <AcmLaunchLink links={[{ id: 'search', text: t('search.new.tab'), href: '/search' }]} />
+                <AcmButton
+                    href={'/search'}
+                    variant={ButtonVariant.link}
+                    component="a"
+                    target="_blank"
+                    rel="noreferrer"
+                    id={'newsearchtab'}
+                    icon={<AcmIcon icon={AcmIconVariant.openNewTab} />}
+                    iconPosition="right"
+                >
+                    {t('search.new.tab')}
+                </AcmButton>
             </AcmActionGroup>
         </div>
     )
 }
 
 export default function SearchPage() {
+    const [, setRoute] = useRecoilState(acmRouteState)
+    useEffect(() => setRoute(AcmRoute.Search), [setRoute])
     // Only using setCurrentQuery to trigger a re-render
     // useEffect using window.location to trigger re-render doesn't work cause react hooks can't use window
     // eslint-disable-next-line @typescript-eslint/no-unused-vars
@@ -223,6 +252,7 @@ export default function SearchPage() {
     const [currentQuery, setCurrentQuery] = useState(searchQuery)
     const [selectedSearch, setSelectedSearch] = useState('Saved searches')
     const [queryErrors, setQueryErrors] = useState(false)
+
     useEffect(() => {
         setCurrentQuery(currentQuery)
     }, [currentQuery])
@@ -231,16 +261,33 @@ export default function SearchPage() {
             setSelectedSearch('Saved searches')
         }
     }, [searchQuery])
+
     const query = convertStringToQuery(searchQuery)
-    const { t } = useTranslation(['search'])
+
+    const [queryMessages, setQueryMessages] = useState<any[]>([])
+    const msgQuery = useGetMessagesQuery({
+        client: process.env.NODE_ENV === 'test' ? undefined : searchClient,
+    })
+
+    useEffect(() => {
+        if (msgQuery.data?.messages) {
+            setQueryMessages(msgQuery.data?.messages)
+        }
+    }, [queryMessages, msgQuery])
+
     return (
-        <AcmPage>
-            <AcmPageHeader title={t('search')} />
-            <RenderDropDownAndNewTab
-                selectedSearch={selectedSearch}
-                setSelectedSearch={setSelectedSearch}
-                setCurrentQuery={setCurrentQuery}
-            />
+        <AcmPage
+            header={
+                <div>
+                    <HeaderWithNotification messages={queryMessages} />
+                    <RenderDropDownAndNewTab
+                        selectedSearch={selectedSearch}
+                        setSelectedSearch={setSelectedSearch}
+                        setCurrentQuery={setCurrentQuery}
+                    />
+                </div>
+            }
+        >
             <AcmScrollable>
                 <RenderSearchBar
                     setSelectedSearch={setSelectedSearch}
