@@ -1,8 +1,11 @@
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
+
 import _ from 'lodash'
-import React from 'react'
+import { Label, LabelGroup } from '@patternfly/react-core'
 import { Link } from 'react-router-dom'
 import moment from 'moment'
-import { AcmLabels } from '@stolostron/ui-components'
+import { AcmLabels } from '@open-cluster-management/ui-components'
 
 // eslint-disable-next-line import/no-anonymous-default-export
 const searchDefinitions: any = {
@@ -31,7 +34,7 @@ const searchDefinitions: any = {
                 header: 'Dashboard',
                 sort: 'dashboard',
                 cell: (item: any) => {
-                    return CreateDashboardLink(item)
+                    return CreateApplicationLink(item)
                 },
             },
             {
@@ -1014,6 +1017,56 @@ const searchDefinitions: any = {
             },
         ],
     },
+    policyreport: {
+        columns: [
+            {
+                header: 'Name',
+                sort: 'name',
+                cell: (item: any) => {
+                    return CreateDetailsLink(item)
+                },
+            },
+            {
+                header: 'Scope',
+                sort: 'scope',
+                cell: 'scope',
+                tooltip: 'Scope refers to the cluster associated to the PolicyReport.',
+            },
+            {
+                header: 'Critical',
+                sort: 'critical',
+                cell: 'critical',
+            },
+            {
+                header: 'Important',
+                sort: 'important',
+                cell: 'important',
+            },
+            {
+                header: 'Moderate',
+                sort: 'moderate',
+                cell: 'moderate',
+            },
+            {
+                header: 'Low',
+                sort: 'low',
+                cell: 'low',
+            },
+            {
+                header: 'Rules',
+                cell: (item: any) => {
+                    return FormatPolicyReportPolicies(item)
+                },
+                tooltip: `Use the rules filter to search for PolicyReports that contain a specific rule.`,
+            },
+            {
+                header: 'Categories',
+                cell: (item: any) => {
+                    return FormatPolicyReportCategories(item.category)
+                },
+            },
+        ],
+    },
     release: {
         columns: [
             {
@@ -1327,10 +1380,18 @@ export function CreateDetailsLink(item: any) {
     switch (item.kind) {
         case 'cluster':
             return <a href={`/multicloud/clusters/${item.name}/overview`}>{item.name}</a>
+
         case 'application':
-            if (item.apigroup === 'app.k8s.io') {
+            if (item.apigroup === 'app.k8s.io' || item.apigroup === 'argoproj.io') {
                 // only redirect to apps page if it is an ACM application
-                return <a href={`/multicloud/applications/${item.namespace}/${item.name}`}>{item.name}</a>
+
+                return (
+                    <a
+                        href={`/multicloud/applications/${item.namespace}/${item.name}?apiVersion=${item.apigroup}%2F${item.apiversion}&cluster=${item.cluster}`}
+                    >
+                        {item.name}
+                    </a>
+                )
             }
             return (
                 <Link
@@ -1364,6 +1425,16 @@ export function CreateDetailsLink(item: any) {
                     {item.name}
                 </Link>
             )
+        case 'policyreport':
+            return (
+                <a
+                    href={`/multicloud/clusters/${item.namespace}/overview?${encodeURIComponent(
+                        'showClusterIssues=true'
+                    )}`}
+                >
+                    {item.name}
+                </a>
+            )
         default:
             return (
                 <Link
@@ -1381,11 +1452,13 @@ export function CreateDetailsLink(item: any) {
     }
 }
 
-export function CreateDashboardLink(item: any) {
-    if (item.dashboard !== null && item.dashboard !== '') {
+export function CreateApplicationLink(item: any) {
+    if (item.apiversion && item.apigroup) {
+        const apiversion = encodeURIComponent(`${item.apigroup}/${item.apiversion}`)
+        const link = `multicloud/applications/${item.namespace}/${item.name}?apiVersion=${apiversion}`
         return (
-            <a target="_blank" rel="noopener noreferrer" href={item.dashboard}>
-                {/* TODO Not translating - caused issue: https://github.com/stolostron/backlog/issues/9184 */}
+            <a target="_blank" rel="noopener noreferrer" href={link}>
+                {/* TODO Not translating - caused issue: https://github.com/open-cluster-management/backlog/issues/9184 */}
                 {'Launch health view'}
             </a>
         )
@@ -1397,7 +1470,7 @@ export function CreateExternalLink(item: any) {
     if (item.consoleURL) {
         return (
             <a target="_blank" rel="noopener noreferrer" href={`${item.consoleURL}`}>
-                {/* TODO Not translating - caused issue: https://github.com/stolostron/backlog/issues/9184 */}
+                {/* TODO Not translating - caused issue: https://github.com/open-cluster-management/backlog/issues/9184 */}
                 {'Launch'}
             </a>
         )
@@ -1416,4 +1489,41 @@ export function FormatLabels(item: any) {
     return '-'
 }
 
+export function FormatPolicyReportPolicies(item: any) {
+    if (item.rules) {
+        const policyArray = item.rules.split('; ')
+        const policiesToHide = policyArray.slice(2)
+        return (
+            <LabelGroup collapsedText={`${policiesToHide.length} more`} expandedText={'Show less'} numLabels={2}>
+                {policyArray.map((policy: any, index: number) => {
+                    return (
+                        <Label
+                            style={{ backgroundColor: '#fff', padding: '0 .25rem 0 0' }}
+                            key={policy}
+                            render={({ content }) => (
+                                <div>
+                                    {content}
+                                    {index < policyArray.length - 1 && ', '}
+                                </div>
+                            )}
+                        >
+                            {policy}
+                        </Label>
+                    )
+                })}
+            </LabelGroup>
+        )
+    }
+    return '-'
+}
+
+export function FormatPolicyReportCategories(data: string) {
+    if (data) {
+        const dataArray = data.split('; ')
+        const dataToHide = dataArray.slice(3)
+        return <AcmLabels labels={dataArray} collapse={dataToHide} />
+    }
+    return '-'
+}
+
 export default searchDefinitions
