@@ -29,7 +29,6 @@ const path__default = _interopDefault(path);
 const pluginHelpers = require('@graphql-codegen/plugin-helpers');
 const core = require('@graphql-codegen/core');
 const chalk = _interopDefault(require('chalk'));
-const indentString = _interopDefault(require('indent-string'));
 const logSymbols = _interopDefault(require('log-symbols'));
 const ansiEscapes = _interopDefault(require('ansi-escapes'));
 const wrapAnsi = _interopDefault(require('wrap-ansi'));
@@ -177,6 +176,40 @@ const lifecycleHooks = (_hooks = {}) => {
     };
 };
 
+/**
+Indent each line in a string.
+@param string - The string to indent.
+@param count - How many times you want `options.indent` repeated. Default: `1`.
+@example
+```
+import indentString from 'indent-string';
+indentString('Unicorns\nRainbows', 4);
+//=> '    Unicorns\n    Rainbows'
+indentString('Unicorns\nRainbows', 4, {indent: '♥'});
+//=> '♥♥♥♥Unicorns\n♥♥♥♥Rainbows'
+```
+*/
+function indentString(string, count = 1, options = {}) {
+    const { indent = ' ', includeEmptyLines = false } = options;
+    if (typeof string !== 'string') {
+        throw new TypeError(`Expected \`input\` to be a \`string\`, got \`${typeof string}\``);
+    }
+    if (typeof count !== 'number') {
+        throw new TypeError(`Expected \`count\` to be a \`number\`, got \`${typeof count}\``);
+    }
+    if (count < 0) {
+        throw new RangeError(`Expected \`count\` to be at least 0, got \`${count}\``);
+    }
+    if (typeof indent !== 'string') {
+        throw new TypeError(`Expected \`options.indent\` to be a \`string\`, got \`${typeof indent}\``);
+    }
+    if (count === 0) {
+        return string;
+    }
+    const regex = includeEmptyLines ? /^/gm : /^(?!\s*$)/gm;
+    return string.replace(regex, indent.repeat(count));
+}
+
 const UpdateRenderer = require('listr-update-renderer');
 class Renderer {
     constructor(tasks, options) {
@@ -453,6 +486,7 @@ async function loadSchema(schemaPointers, config) {
             ...defaultSchemaLoadOptions,
             loaders,
             ...config,
+            ...config.config,
         });
         return schema;
     }
@@ -482,6 +516,7 @@ async function loadDocuments(documentPointers, config) {
         ignore: Object.keys(config.generates).map(p => path.join(process.cwd(), p)),
         loaders,
         ...config,
+        ...config.config,
     });
     return loadedFromToolkit;
 }
@@ -583,7 +618,7 @@ function buildOptions() {
                 if (typeof watch === 'string' || Array.isArray(watch)) {
                     return watch;
                 }
-                return true;
+                return !!watch;
             },
         },
         r: {
@@ -1386,6 +1421,15 @@ const plugins = [
         shouldBeSelected: () => false,
         defaultExtension: '.ts',
     },
+    {
+        name: `Urql Introspection ${italic('(for Urql Client)')}`,
+        package: '@graphql-codegen/urql-introspection',
+        value: 'urql-introspection',
+        pathInRepo: 'other/urql-introspection',
+        available: hasTag(Tags.browser),
+        shouldBeSelected: () => false,
+        defaultExtension: '.ts',
+    },
 ];
 function hasTag(tag) {
     return (tags) => tags.includes(tag);
