@@ -3,7 +3,6 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 import './selections.css';
-import * as browser from '../../../../base/browser/browser.js';
 import { DynamicViewOverlay } from '../../view/dynamicViewOverlay.js';
 import { editorInactiveSelection, editorSelectionBackground, editorSelectionForeground } from '../../../../platform/theme/common/colorRegistry.js';
 import { registerThemingParticipant } from '../../../../platform/theme/common/themeService.js';
@@ -27,19 +26,15 @@ function toStyledRange(item) {
 function toStyled(item) {
     return new LineVisibleRangesWithStyle(item.lineNumber, item.ranges.map(toStyledRange));
 }
-// TODO@Alex: Remove this once IE11 fixes Bug #524217
-// The problem in IE11 is that it does some sort of auto-zooming to accomodate for displays with different pixel density.
-// Unfortunately, this auto-zooming is buggy around dealing with rounded borders
-const isIEWithZoomingIssuesNearRoundedBorders = browser.isEdge;
 export class SelectionsOverlay extends DynamicViewOverlay {
     constructor(context) {
         super();
         this._previousFrameVisibleRangesWithStyle = [];
         this._context = context;
         const options = this._context.configuration.options;
-        this._lineHeight = options.get(51 /* lineHeight */);
-        this._roundedSelection = options.get(82 /* roundedSelection */);
-        this._typicalHalfwidthCharacterWidth = options.get(36 /* fontInfo */).typicalHalfwidthCharacterWidth;
+        this._lineHeight = options.get(56 /* lineHeight */);
+        this._roundedSelection = options.get(88 /* roundedSelection */);
+        this._typicalHalfwidthCharacterWidth = options.get(40 /* fontInfo */).typicalHalfwidthCharacterWidth;
         this._selections = [];
         this._renderResult = null;
         this._context.addEventHandler(this);
@@ -52,9 +47,9 @@ export class SelectionsOverlay extends DynamicViewOverlay {
     // --- begin event handlers
     onConfigurationChanged(e) {
         const options = this._context.configuration.options;
-        this._lineHeight = options.get(51 /* lineHeight */);
-        this._roundedSelection = options.get(82 /* roundedSelection */);
-        this._typicalHalfwidthCharacterWidth = options.get(36 /* fontInfo */).typicalHalfwidthCharacterWidth;
+        this._lineHeight = options.get(56 /* lineHeight */);
+        this._roundedSelection = options.get(88 /* roundedSelection */);
+        this._typicalHalfwidthCharacterWidth = options.get(40 /* fontInfo */).typicalHalfwidthCharacterWidth;
         return true;
     }
     onCursorStateChanged(e) {
@@ -187,7 +182,7 @@ export class SelectionsOverlay extends DynamicViewOverlay {
         const _linesVisibleRanges = ctx.linesVisibleRangesForRange(selection, true) || [];
         const linesVisibleRanges = _linesVisibleRanges.map(toStyled);
         const visibleRangesHaveGaps = this._visibleRangesHaveGaps(linesVisibleRanges);
-        if (!isIEWithZoomingIssuesNearRoundedBorders && !visibleRangesHaveGaps && this._roundedSelection) {
+        if (!visibleRangesHaveGaps && this._roundedSelection) {
             this._enrichVisibleRangesWithStyle(ctx.visibleRange, linesVisibleRanges, previousFrame);
         }
         // The visible ranges are sorted TOP-BOTTOM and LEFT-RIGHT
