@@ -1,4 +1,4 @@
-const fastify = require('../fastify')()
+const fastify = require('../fastify')({ logger: true })
 
 const opts = {
   schema: {
@@ -22,5 +22,4 @@ fastify.listen(3000, function (err) {
   if (err) {
     throw err
   }
-  console.log(`server listening on ${fastify.server.address().port}`)
 })
