@@ -7,21 +7,22 @@ const { readFileSync, createReadStream } = require('fs')
 const { Readable } = require('stream')
 const { kSocket } = require('../lib/core/symbols')
 const EE = require('events')
+const { kConnect } = require('../lib/core/symbols')
 
 test('basic get', (t) => {
-  t.plan(23)
+  t.plan(24)
 
   const server = createServer((req, res) => {
-    t.strictEqual('/', req.url)
-    t.strictEqual('GET', req.method)
-    t.strictEqual(`localhost:${server.address().port}`, req.headers.host)
-    t.strictEqual(undefined, req.headers.foo)
-    t.strictEqual('bar', req.headers.bar)
-    t.strictEqual(undefined, req.headers['content-length'])
+    t.equal('/', req.url)
+    t.equal('GET', req.method)
+    t.equal(`localhost:${server.address().port}`, req.headers.host)
+    t.equal(undefined, req.headers.foo)
+    t.equal('bar', req.headers.bar)
+    t.equal(undefined, req.headers['content-length'])
     res.setHeader('Content-Type', 'text/plain')
     res.end('hello')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   const reqHeaders = {
     foo: undefined,
@@ -29,8 +30,12 @@ test('basic get', (t) => {
   }
 
   server.listen(0, () => {
-    const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    const client = new Client(`http://localhost:${server.address().port}`, {
+      keepAliveTimeout: 300e3
+    })
+    t.teardown(client.close.bind(client))
+
+    t.equal(client.url.origin, `http://localhost:${server.address().port}`)
 
     const signal = new EE()
     client.request({
@@ -41,19 +46,19 @@ test('basic get', (t) => {
     }, (err, data) => {
       t.error(err)
       const { statusCode, headers, body } = data
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(signal.listenerCount('abort'), 1)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(signal.listenerCount('abort'), 1)
+      t.equal(headers['content-type'], 'text/plain')
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual(signal.listenerCount('abort'), 0)
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal(signal.listenerCount('abort'), 0)
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
-    t.strictEqual(signal.listenerCount('abort'), 1)
+    t.equal(signal.listenerCount('abort'), 1)
 
     client.request({
       path: '/',
@@ -61,14 +66,14 @@ test('basic get', (t) => {
       headers: reqHeaders
     }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -78,22 +83,22 @@ test('basic head', (t) => {
   t.plan(14)
 
   const server = createServer((req, res) => {
-    t.strictEqual('/123', req.url)
-    t.strictEqual('HEAD', req.method)
-    t.strictEqual(`localhost:${server.address().port}`, req.headers.host)
+    t.equal('/123', req.url)
+    t.equal('HEAD', req.method)
+    t.equal(`localhost:${server.address().port}`, req.headers.host)
     res.setHeader('content-type', 'text/plain')
     res.end('hello')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({ path: '/123', method: 'HEAD' }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
       body
         .resume()
         .on('end', () => {
@@ -103,8 +108,8 @@ test('basic head', (t) => {
 
     client.request({ path: '/123', method: 'HEAD' }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
       body
         .resume()
         .on('end', () => {
@@ -118,28 +123,28 @@ test('get with host header', (t) => {
   t.plan(7)
 
   const server = createServer((req, res) => {
-    t.strictEqual('/', req.url)
-    t.strictEqual('GET', req.method)
-    t.strictEqual('example.com', req.headers.host)
+    t.equal('/', req.url)
+    t.equal('GET', req.method)
+    t.equal('example.com', req.headers.host)
     res.setHeader('content-type', 'text/plain')
     res.end('hello from ' + req.headers.host)
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({ path: '/', method: 'GET', headers: { host: 'example.com' } }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello from example.com', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello from example.com', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -149,22 +154,22 @@ test('head with host header', (t) => {
   t.plan(7)
 
   const server = createServer((req, res) => {
-    t.strictEqual('/', req.url)
-    t.strictEqual('HEAD', req.method)
-    t.strictEqual('example.com', req.headers.host)
+    t.equal('/', req.url)
+    t.equal('HEAD', req.method)
+    t.equal('example.com', req.headers.host)
     res.setHeader('content-type', 'text/plain')
     res.end('hello from ' + req.headers.host)
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({ path: '/', method: 'HEAD', headers: { host: 'example.com' } }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
-      t.strictEqual(headers['content-type'], 'text/plain')
+      t.equal(statusCode, 200)
+      t.equal(headers['content-type'], 'text/plain')
       body
         .resume()
         .on('end', () => {
@@ -176,8 +181,8 @@ test('head with host header', (t) => {
 
 function postServer (t, expected) {
   return function (req, res) {
-    t.strictEqual(req.url, '/')
-    t.strictEqual(req.method, 'POST')
+    t.equal(req.url, '/')
+    t.equal(req.method, 'POST')
     t.notSame(req.headers['content-length'], null)
 
     req.setEncoding('utf8')
@@ -186,7 +191,7 @@ function postServer (t, expected) {
     req.on('data', function (d) { data += d })
 
     req.on('end', () => {
-      t.strictEqual(data, expected)
+      t.equal(data, expected)
       res.end('hello')
     })
   }
@@ -198,22 +203,22 @@ test('basic POST with string', (t) => {
   const expected = readFileSync(__filename, 'utf8')
 
   const server = createServer(postServer(t, expected))
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({ path: '/', method: 'POST', body: expected }, (err, data) => {
       t.error(err)
-      t.strictEqual(data.statusCode, 200)
+      t.equal(data.statusCode, 200)
       const bufs = []
       data.body
         .on('data', (buf) => {
           bufs.push(buf)
         })
         .on('end', () => {
-          t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+          t.equal('hello', Buffer.concat(bufs).toString('utf8'))
         })
     })
   })
@@ -223,21 +228,21 @@ test('basic POST with empty string', (t) => {
   t.plan(7)
 
   const server = createServer(postServer(t, ''))
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({ path: '/', method: 'POST', body: '' }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
+      t.equal(statusCode, 200)
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -249,11 +254,11 @@ test('basic POST with string and content-length', (t) => {
   const expected = readFileSync(__filename, 'utf8')
 
   const server = createServer(postServer(t, expected))
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({
       path: '/',
@@ -264,13 +269,13 @@ test('basic POST with string and content-length', (t) => {
       body: expected
     }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
+      t.equal(statusCode, 200)
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -282,21 +287,21 @@ test('basic POST with Buffer', (t) => {
   const expected = readFileSync(__filename)
 
   const server = createServer(postServer(t, expected.toString()))
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({ path: '/', method: 'POST', body: expected }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
+      t.equal(statusCode, 200)
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -308,11 +313,11 @@ test('basic POST with stream', (t) => {
   const expected = readFileSync(__filename, 'utf8')
 
   const server = createServer(postServer(t, expected))
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({
       path: '/',
@@ -320,17 +325,17 @@ test('basic POST with stream', (t) => {
       headers: {
         'content-length': Buffer.byteLength(expected)
       },
-      requestTimeout: 0,
+      headersTimeout: 0,
       body: createReadStream(__filename)
     }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
+      t.equal(statusCode, 200)
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -344,31 +349,31 @@ test('basic POST with custom stream', (t) => {
       res.end('hello')
     })
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     const body = new EE()
     body.pipe = () => {}
     client.request({
       path: '/',
       method: 'POST',
-      requestTimeout: 0,
+      headersTimeout: 0,
       body
     }, (err, data) => {
       t.error(err)
-      t.strictEqual(data.statusCode, 200)
+      t.equal(data.statusCode, 200)
       const bufs = []
       data.body.on('data', (buf) => {
         bufs.push(buf)
       })
       data.body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
-    t.strictDeepEqual(client.busy, true)
+    t.strictSame(client.busy, true)
 
     body.on('close', () => {
       body.emit('end')
@@ -394,10 +399,10 @@ test('basic POST with transfer encoding: chunked', (t) => {
 
   let body
   const server = createServer(function (req, res) {
-    t.strictEqual(req.url, '/')
-    t.strictEqual(req.method, 'POST')
+    t.equal(req.url, '/')
+    t.equal(req.method, 'POST')
     t.same(req.headers['content-length'], null)
-    t.strictEqual(req.headers['transfer-encoding'], 'chunked')
+    t.equal(req.headers['transfer-encoding'], 'chunked')
 
     body.push(null)
 
@@ -407,15 +412,15 @@ test('basic POST with transfer encoding: chunked', (t) => {
     req.on('data', function (d) { data += d })
 
     req.on('end', () => {
-      t.strictEqual(data, 'asd')
+      t.equal(data, 'asd')
       res.end('hello')
     })
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     body = new Readable({
       read () { }
@@ -428,13 +433,13 @@ test('basic POST with transfer encoding: chunked', (t) => {
       body
     }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
+      t.equal(statusCode, 200)
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -447,11 +452,11 @@ test('basic POST with empty stream', (t) => {
     t.same(req.headers['content-length'], 0)
     req.pipe(res)
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     const body = new Readable({
       autoDestroy: false,
@@ -462,7 +467,7 @@ test('basic POST with empty stream', (t) => {
       }
     }).on('end', () => {
       process.nextTick(() => {
-        t.strictEqual(body.destroyed, true)
+        t.equal(body.destroyed, true)
       })
     })
     body.push(null)
@@ -490,11 +495,11 @@ test('10 times GET', (t) => {
   const server = createServer((req, res) => {
     res.end(req.url)
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     for (var i = 0; i < num; i++) {
       makeRequest(i)
@@ -503,13 +508,13 @@ test('10 times GET', (t) => {
     function makeRequest (i) {
       client.request({ path: '/' + i, method: 'GET' }, (err, { statusCode, headers, body }) => {
         t.error(err)
-        t.strictEqual(statusCode, 200)
+        t.equal(statusCode, 200)
         const bufs = []
         body.on('data', (buf) => {
           bufs.push(buf)
         })
         body.on('end', () => {
-          t.strictEqual('/' + i, Buffer.concat(bufs).toString('utf8'))
+          t.equal('/' + i, Buffer.concat(bufs).toString('utf8'))
         })
       })
     }
@@ -523,11 +528,11 @@ test('10 times HEAD', (t) => {
   const server = createServer((req, res) => {
     res.end(req.url)
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     for (var i = 0; i < num; i++) {
       makeRequest(i)
@@ -536,7 +541,7 @@ test('10 times HEAD', (t) => {
     function makeRequest (i) {
       client.request({ path: '/' + i, method: 'HEAD' }, (err, { statusCode, headers, body }) => {
         t.error(err)
-        t.strictEqual(statusCode, 200)
+        t.equal(statusCode, 200)
         body
           .resume()
           .on('end', () => {
@@ -555,22 +560,22 @@ test('Set-Cookie', (t) => {
     res.setHeader('Set-Cookie', ['a cookie', 'another cookie', 'more cookies'])
     res.end('hello')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({ path: '/', method: 'GET' }, (err, { statusCode, headers, body }) => {
       t.error(err)
-      t.strictEqual(statusCode, 200)
-      t.strictDeepEqual(headers['set-cookie'], ['a cookie', 'another cookie', 'more cookies'])
+      t.equal(statusCode, 200)
+      t.strictSame(headers['set-cookie'], ['a cookie', 'another cookie', 'more cookies'])
       const bufs = []
       body.on('data', (buf) => {
         bufs.push(buf)
       })
       body.on('end', () => {
-        t.strictEqual('hello', Buffer.concat(bufs).toString('utf8'))
+        t.equal('hello', Buffer.concat(bufs).toString('utf8'))
       })
     })
   })
@@ -580,14 +585,14 @@ test('ignore request header mutations', (t) => {
   t.plan(2)
 
   const server = createServer((req, res) => {
-    t.strictEqual(req.headers.test, 'test')
+    t.equal(req.headers.test, 'test')
     res.end()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     const headers = { test: 'test' }
     client.request({
@@ -608,15 +613,15 @@ test('url-like url', (t) => {
   const server = createServer((req, res) => {
     res.end()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client({
       hostname: 'localhost',
       port: server.address().port,
-      protocol: 'http'
+      protocol: 'http:'
     })
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({ path: '/', method: 'GET' }, (err, data) => {
       t.error(err)
@@ -631,18 +636,18 @@ test('an absolute url as path', (t) => {
   const path = 'http://example.com'
 
   const server = createServer((req, res) => {
-    t.strictEqual(req.url, path)
+    t.equal(req.url, path)
     res.end()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client({
       hostname: 'localhost',
       port: server.address().port,
-      protocol: 'http'
+      protocol: 'http:'
     })
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({ path, method: 'GET' }, (err, data) => {
       t.error(err)
@@ -657,15 +662,15 @@ test('multiple destroy callback', (t) => {
   const server = createServer((req, res) => {
     res.end()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client({
       hostname: 'localhost',
       port: server.address().port,
-      protocol: 'http'
+      protocol: 'http:'
     })
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({ path: '/', method: 'GET' }, (err, data) => {
       t.error(err)
@@ -690,13 +695,13 @@ test('only one streaming req at a time', (t) => {
   const server = createServer((req, res) => {
     req.pipe(res)
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`, {
       pipelining: 4
     })
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({
       path: '/',
@@ -720,12 +725,12 @@ test('only one streaming req at a time', (t) => {
         body: new Readable({
           read () {
             setImmediate(() => {
-              t.strictEqual(client.busy, true)
+              t.equal(client.busy, true)
               this.push(null)
             })
           }
         }).on('resume', () => {
-          t.strictEqual(client.size, 1)
+          t.equal(client.size, 1)
         })
       }, (err, data) => {
         t.error(err)
@@ -735,7 +740,7 @@ test('only one streaming req at a time', (t) => {
             t.pass()
           })
       })
-      t.strictEqual(client.busy, true)
+      t.equal(client.busy, true)
     })
   })
 })
@@ -746,11 +751,11 @@ test('300 requests succeed', (t) => {
   const server = createServer((req, res) => {
     res.end('asd')
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     for (let n = 0; n < 300; ++n) {
       client.request({
@@ -759,7 +764,7 @@ test('300 requests succeed', (t) => {
       }, (err, data) => {
         t.error(err)
         data.body.on('data', (chunk) => {
-          t.strictEqual(chunk.toString(), 'asd')
+          t.equal(chunk.toString(), 'asd')
         }).on('end', () => {
           t.pass()
         })
@@ -800,11 +805,11 @@ test('increase pipelining', (t) => {
   const server = createServer((req, res) => {
     req.resume()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.destroy.bind(client))
+    t.teardown(client.destroy.bind(client))
 
     client.request({
       path: '/',
@@ -824,13 +829,13 @@ test('increase pipelining', (t) => {
       }
     })
 
-    t.strictEqual(client.running, 0)
+    t.equal(client.running, 0)
     client.on('connect', () => {
-      t.strictEqual(client.running, 0)
+      t.equal(client.running, 0)
       process.nextTick(() => {
-        t.strictEqual(client.running, 1)
+        t.equal(client.running, 1)
         client.pipelining = 3
-        t.strictEqual(client.running, 2)
+        t.equal(client.running, 2)
       })
     })
   })
@@ -844,11 +849,11 @@ test('destroy in push', (t) => {
     res.write('asd')
     _res = res
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({ path: '/', method: 'GET' }, (err, { body }) => {
       t.error(err)
@@ -870,7 +875,7 @@ test('destroy in push', (t) => {
         buf = chunk.toString()
         _res.end()
       }).on('end', () => {
-        t.strictEqual('asd', buf)
+        t.equal('asd', buf)
       })
     })
   })
@@ -882,17 +887,17 @@ test('non recoverable socket error fails pending request', (t) => {
   const server = createServer((req, res) => {
     res.end()
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     client.request({ path: '/', method: 'GET' }, (err, data) => {
-      t.strictEqual(err.message, 'kaboom')
+      t.equal(err.message, 'kaboom')
     })
     client.request({ path: '/', method: 'GET' }, (err, data) => {
-      t.strictEqual(err.message, 'kaboom')
+      t.equal(err.message, 'kaboom')
     })
     client.on('connect', () => {
       client[kSocket].destroy(new Error('kaboom'))
@@ -906,11 +911,11 @@ test('POST empty with error', (t) => {
   const server = createServer((req, res) => {
     req.pipe(res)
   })
-  t.tearDown(server.close.bind(server))
+  t.teardown(server.close.bind(server))
 
   server.listen(0, () => {
     const client = new Client(`http://localhost:${server.address().port}`)
-    t.tearDown(client.close.bind(client))
+    t.teardown(client.close.bind(client))
 
     const body = new Readable({
       read () {
@@ -924,7 +929,33 @@ test('POST empty with error', (t) => {
     })
 
     client.request({ path: '/', method: 'POST', body }, (err, data) => {
-      t.strictEqual(err.message, 'asd')
+      t.equal(err.message, 'asd')
+    })
+  })
+})
+
+test('busy', (t) => {
+  t.plan(2)
+
+  const server = createServer((req, res) => {
+    req.pipe(res)
+  })
+  t.teardown(server.close.bind(server))
+
+  server.listen(0, () => {
+    const client = new Client(`http://localhost:${server.address().port}`, {
+      pipelining: 1
+    })
+    t.teardown(client.close.bind(client))
+
+    client[kConnect](() => {
+      client.request({
+        path: '/',
+        method: 'GET'
+      }, (err) => {
+        t.error(err)
+      })
+      t.equal(client.busy, true)
     })
   })
 })
