@@ -8,8 +8,8 @@ const get = require('simple-get').concat
 
 const instance = Fastify()
 
-t.plan(12)
-t.tearDown(instance.close.bind(instance))
+t.plan(13)
+t.teardown(instance.close.bind(instance))
 
 const target = http.createServer((req, res) => {
   t.pass('request proxied')
@@ -24,16 +24,19 @@ const target = http.createServer((req, res) => {
 })
 
 instance.head('/', (request, reply) => {
+  t.pass('head received')
   reply.from()
 })
 
-t.tearDown(target.close.bind(target))
+t.teardown(target.close.bind(target))
 
 target.listen(0, (err) => {
   t.error(err)
 
   instance.register(From, {
-    base: `http://localhost:${target.address().port}`
+    base: `http://localhost:${target.address().port}`,
+    // Use node core HTTP, Undici requires spec compliance
+    http: {}
   })
 
   instance.listen(0, (err) => {
