@@ -8,7 +8,7 @@ const got = require('got')
 test('http -> http2 crash', async (t) => {
   const instance = Fastify()
 
-  t.tearDown(instance.close.bind(instance))
+  t.teardown(instance.close.bind(instance))
 
   const target = Fastify({
     http2: true
@@ -25,7 +25,7 @@ test('http -> http2 crash', async (t) => {
     reply.from()
   })
 
-  t.tearDown(target.close.bind(target))
+  t.teardown(target.close.bind(target))
 
   await target.listen(0)
 
@@ -42,7 +42,7 @@ test('http -> http2 crash', async (t) => {
   } catch (err) {
     t.equal(err.response.statusCode, 503)
     t.match(err.response.headers['content-type'], /application\/json/)
-    t.deepEqual(JSON.parse(err.response.body), {
+    t.same(JSON.parse(err.response.body), {
       statusCode: 503,
       error: 'Service Unavailable',
       message: 'Service Unavailable'
